@@ -142,10 +142,7 @@ class BackTestEngine:
         if cleanBackTestOrders:
             self.__dataSource.truncateBackTestOrders()
 
-        _instance = clazz()
-        _instance.context = self.__backTestContext
-        self.__executeInstance = _instance
-
+        self.__executeInstance = clazz()
         self.__backTestContext.setMarketApi(LocalMarketApi(self.__backTestContext))
         self.__backTestContext.setTradeApi(TradeApi(self.__backTestContext))
         self.__backTestContext.setExecutePeriod(executePeriod)
@@ -174,7 +171,7 @@ class BackTestEngine:
 
     def execute(self):
 
-        self.__executeInstance.init()
+        self.__executeInstance.init(self.__backTestContext)
 
         _startTimeStamp = self.__startTimeMills
         _endTimeStamp = self.__endTimeStampMills
@@ -182,16 +179,16 @@ class BackTestEngine:
 
         while True:
             try:
-                self.__executeInstance.executeStopLoss()
+                self.__executeInstance.executeStopLoss(self.__backTestContext)
             except Exception as e:
                 traceback.print_exc()
             try:
-                self.__executeInstance.executeStopProfit()
+                self.__executeInstance.executeStopProfit(self.__backTestContext)
             except Exception as e:
                 traceback.print_exc()
             try:
                 self.__backTestContext.setExecutingTimeMills(_startTimeStamp)
-                self.__executeInstance.execute()
+                self.__executeInstance.execute(self.__backTestContext)
             except Exception as e:
                 traceback.print_exc()
 
@@ -201,7 +198,7 @@ class BackTestEngine:
                 _startTimeStamp = _startTimeStamp + self.resolveExecutePeriodMills(_executePeriod)
 
         try:
-            self.__executeInstance.destroy()
+            self.__executeInstance.destroy(self.__backTestContext)
         except Exception as e:
             traceback.print_exc()
 
