@@ -4,9 +4,6 @@ from easytradetesting.BackTestOrder import BackTestOrder
 from easytradetesting.DataSource import DataSource
 from easytradesdk import Serializer
 from easytradesdk.entity.Kline import Kline
-from easytradesdk.entity.KlineInterval import KlineInterval
-from easytradesdk.entity.Symbol import Symbol
-from easytradesdk.entity.TC import TC
 
 
 class MySqlDataSource(DataSource):
@@ -40,13 +37,13 @@ class MySqlDataSource(DataSource):
         """
         self.__connection.close()
 
-    def createKlineTable(self, tc: TC, symbol: Symbol, interval: KlineInterval):
+    def createKlineTable(self, tc, symbol, klinePeriod):
 
         """
             创建K线表，若表已经存在则不再进行创建
             :param tc:              交易所
             :param symbol:          交易标的
-            :param interval:   K线周期
+            :param klinePeriod:   K线周期
             :return: 
         """""
         sql = """
@@ -74,7 +71,7 @@ class MySqlDataSource(DataSource):
             ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
         """
 
-        sql = sql.replace("${tableName}", DataSource.resolveKlineTableName(tc, symbol, interval))
+        sql = sql.replace("${tableName}", DataSource.resolveKlineTableName(tc, symbol, klinePeriod))
         cursor = self.__connection.cursor()
 
         try:
@@ -82,21 +79,21 @@ class MySqlDataSource(DataSource):
         finally:
             cursor.close()
 
-    def saveKline(self, tc: TC, symbol: Symbol, interval: KlineInterval, kline):
+    def saveKline(self, tc, symbol, klinePeriod, kline):
 
         """
             保存单个K线数据, K 线重复将不会报错，可以重复执行
             :param tc:              交易所
             :param symbol:          交易标的
             :param kline:           k线对象
-            :param interval:   k线时间戳
+            :param klinePeriod:   k线时间戳
             :return:
         """
         cursor = self.__connection.cursor()
         if kline is None:
             return
 
-        sql = 'insert ignore into ' + DataSource.resolveKlineTableName(tc, symbol, interval) + \
+        sql = 'insert ignore into ' + DataSource.resolveKlineTableName(tc, symbol, klinePeriod) + \
               ' (timeMills,endTimeMills,startTime,endTime,tc,symbol,timeInterval,openingPrice,closingPrice,highPrice,lowPrice,' \
               ' volume,quantity,cnt,buyVolume,buyQuantity)' \
               ' values(%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)'
@@ -113,13 +110,13 @@ class MySqlDataSource(DataSource):
         finally:
             cursor.close()
 
-    def saveKlines(self, tc: TC, symbol: Symbol, interval: KlineInterval, klines):
+    def saveKlines(self, tc, symbol, klinePeriod, klines):
 
         """
             批量保存k线数据，如果遇到重复，将报错并回滚
             :param tc:      交易所
             :param symbol:  交易标的
-            :param interval:  k线周期
+            :param klinePeriod:  k线周期
             :param klines:  K线对象列表
             :return:
         """
@@ -132,7 +129,7 @@ class MySqlDataSource(DataSource):
                      klines[i].highPrice, klines[i].lowPrice,
                      klines[i].volume, klines[i].quantity,
                      klines[i].cnt, klines[i].buyVolume, klines[i].buyQuantity) for i in range(0, len(klines)))
-            sql = 'insert into ' + DataSource.resolveKlineTableName(tc, symbol, interval) + \
+            sql = 'insert into ' + DataSource.resolveKlineTableName(tc, symbol, klinePeriod) + \
                   ' (timeMills,endTimeMills,startTime,endTime,tc,symbol,timeInterval,openingPrice,closingPrice,highPrice,lowPrice,' \
                   ' volume,quantity,cnt,buyVolume,buyQuantity)' \
                   ' values(%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)'
@@ -144,13 +141,13 @@ class MySqlDataSource(DataSource):
             finally:
                 cursor.close()
 
-    def queryKline(self, tc: TC, symbol: Symbol, interval: KlineInterval, startTimeMills=None, endTimeMills=None, limit=200):
+    def queryKline(self, tc, symbol, klinePeriod, startTimeMills=None, endTimeMills=None, limit=200):
 
         """
             从数据库查询 K 线数据
             :param tc:              交易所
             :param symbol:          交易标的
-            :param interval:   K 线周期
+            :param klinePeriod:     K 线周期
             :param startTimeMills:   开始时间戳   开始时间戳和结束时间戳两者必须填一个
             :param endTimeMills:     结束时间戳
             :param limit:           记录数，默认 200
@@ -160,7 +157,7 @@ class MySqlDataSource(DataSource):
         if startTimeMills is None and endTimeMills is None:
             raise Exception("startTimeMills or endTimeMills is required")
         params = []
-        sql = "select * from " + DataSource.resolveKlineTableName(tc, symbol, interval) + " where 1=1"
+        sql = "select * from " + DataSource.resolveKlineTableName(tc, symbol, klinePeriod) + " where 1=1"
         if startTimeMills is not None:
             sql += " and timeMills >= %s"
             params.append(startTimeMills)
@@ -178,19 +175,19 @@ class MySqlDataSource(DataSource):
         finally:
             cursor.close()
 
-    def queryLatestKline(self, tc: TC, symbol: Symbol, interval: KlineInterval, endTimeMills=None, limit=200):
+    def queryLatestKline(self, tc, symbol, klinePeriod, endTimeMills=None, limit=200):
 
         """
             查询最近的 K 线，按照K线时间升序排序¬
             :param tc:              交易所
             :param symbol:          交易标的
-            :param interval:        K 线周期
+            :param klinePeriod:        K 线周期
             :param endTimeMills:    K线截止时间
             :param limit:           记录数，默认 200
             :return:
         """
         params = []
-        sql = "select * from " + DataSource.resolveKlineTableName(tc, symbol, interval) + " where 1=1 "
+        sql = "select * from " + DataSource.resolveKlineTableName(tc, symbol, klinePeriod) + " where 1=1 "
         if endTimeMills:
             sql += " and timeMills <= %s"
             params.append(endTimeMills)
@@ -208,18 +205,18 @@ class MySqlDataSource(DataSource):
         finally:
             cursor.close()
 
-    def countKline(self, tc: TC, symbol: Symbol, interval: KlineInterval, startTimeMills=None, endTimeMills=None):
+    def countKline(self, tc, symbol, klinePeriod, startTimeMills=None, endTimeMills=None):
         """
             查询 K 线数量
             :param tc:
             :param symbol:
-            :param interval:
+            :param klinePeriod:
             :param startTimeMills:
             :param endTimeMills:
             :return:
         """
         params = []
-        sql = "select count(*) as cnt from " + DataSource.resolveKlineTableName(tc, symbol, interval) + " where 1=1 "
+        sql = "select count(*) as cnt from " + DataSource.resolveKlineTableName(tc, symbol, klinePeriod) + " where 1=1 "
 
         if startTimeMills is not None:
             sql += " and timeMills >= %s"
@@ -362,7 +359,7 @@ class MySqlDataSource(DataSource):
         finally:
             cursor.close()
 
-    def queryBackTestOrders(self, startTimeMills=None, endTimeMills=None, tc: TC = None, symbol: Symbol = None, limit=50):
+    def queryBackTestOrders(self, startTimeMills=None, endTimeMills=None, tc=None, symbol=None, limit=50):
 
         """
             查询回测订单
@@ -377,10 +374,10 @@ class MySqlDataSource(DataSource):
         sql = "select * from " + DataSource.resolveBackTestOrderTableName() + " where 1=1"
 
         if tc:
-            params.append(tc.value)
+            params.append(tc)
             sql += "and tc= %s"
         if symbol:
-            params.append(symbol.value)
+            params.append(symbol)
             sql += "and symbol= %s"
         if startTimeMills:
             params.append(startTimeMills)
